/**
 * Sets the correct style and functionality for the header area.
 *
 * Sets the position, margin, padding and other styles for the header.
 * It also sets the functionality for the search bar, and responsive menu.
 *
 * @since 1.0.0
 */
(function ( $ ) {

	var 
		$body 					= $( 'body' ),
		$window					= $( window ),
		$header					= $( '#gf-header' ),
		$menu                   = $( '#gf-header-menu' ),
		$menuCollapse           = $( '#gf-header-collapse' ),
		$searchForm             = $( '#gf-header-search-form' ),
		$menuToggler            = $( '#gf-header-menu-toggler' ),
		$itemWithChildren       = $( '.menu-item-has-children > a' ),
		$searchFormTogglerLink  = $( '#gf-header-form-toggler-link' );
 
	$itemWithChildren.on( 'click', function ( e ) {

		e.stopPropagation();
		
		var $this    = $( this ),
			$subMenu = $this.next( '.sub-menu' ),
			index    = $( '.menu-item-has-children > a' ).index( this );

		$itemWithChildren.each(function ( i, elem ) {

			if ( i != index ) {
				var $currentItem        = $( elem ),
				    $posibleOpenSubmenu = $currentItem.next( '.sub-menu' );

				$currentItem
					.parent()
					.removeClass( 'current-menu-item' );

				if ( window.matchMedia( '(min-width: 768px)' ).matches ) {
					$posibleOpenSubmenu.fadeOut( 'fast' );	
				} else {
					$posibleOpenSubmenu.slideUp( 'fast' );
				}
			}

		});

		$this
			.parent()
			.toggleClass( 'current-menu-item' );

		if ( window.matchMedia( '(min-width: 768px)' ).matches ) {
			$subMenu.fadeToggle( 'fast' );	
		} else {
			$subMenu.slideToggle( 'fast' );
		}

		return false;

	});

	$searchFormTogglerLink.on( 'click', function ( e ) {

		e.preventDefault();

		var $this = $( this ),
			$icon = $this.find( 'i' );

		if ( $icon.hasClass( 'fa-search' ) ) {
			$icon
				.removeClass( 'fa-search' )
				.addClass( 'fa-times' );
		} else {
			$icon
				.removeClass( 'fa-times' )
				.addClass( 'fa-search' );
		}

		$menu.toggleClass( 'gf-header__menu--hidden' );
		$searchForm.toggleClass( 'gf-header-search-form--shown' );

	});

	$menuToggler.on( 'click', function ( e ) {

		e.preventDefault();

		$menuCollapse.slideToggle( 'fast' );

	});

	$( document ).on( 'click', function ( e ) {

		$itemWithChildren
			.parent()
			.removeClass( 'current-menu-item' );

		if ( window.matchMedia( '(min-width: 768px)' ).matches ) {
			$( '.sub-menu' ).fadeOut( 'fast' );	
		} else {
			$( '.sub-menu' ).slideUp( 'fast' );
		}

	});

	$window.on( 'scroll', function ( e ) {
		if (  $body.hasClass( 'logged-in' ) && $window.get(0).matchMedia("(max-width: 600px)").matches ) {
			if ( $window.scrollTop() >= 1 ) {
				$header
					.addClass( 'gf-header--no-top' );
			} else {
				$header
					.removeClass( 'gf-header--no-top' );
			}
		}
	});

})( jQuery );
