<?php

/**
 * Registers Customizers settings for the theme.
 * 
 * This does include:
 * - Blog section.
 *   - Show featured section.
 *   - Show top stories section.
 *   - Hide sidebar setting.
 * - Footer section.
 *   - Copyright text.
 *   - Social network links.
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'go_first_customize_register' ) ) {
	function go_first_customize_register( $wp_customize ) {
		// Blog
		$wp_customize->add_section( 'blog', array(
			'priority'        => 150,
			'capability'      => 'edit_theme_options',
			'title'           => __( 'Blog', 'go-first' ),
		) );

		$wp_customize->add_setting( 'show_featured', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'show_featured_input', array(
			'priority' => 10,
			'section'  => 'blog',
			'type'     => 'checkbox',
			'settings' => 'show_featured',
			'label'    => __( 'Show Featured Story', 'go-first' ),
		) );

		$wp_customize->add_setting( 'show_top_stories', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
			'capability' 		=> 'edit_theme_options',
		) );

		$wp_customize->add_control( 'show_top_stories_input', array(
			'priority' => 20,
			'section'  => 'blog',
			'type'     => 'checkbox',
			'settings' => 'show_top_stories',
			'label'    => __( 'Show Top Stories', 'go-first' ),
		) );

		$wp_customize->add_setting( 'hide_sidebar', array(
			'default'    		=> false,
			'transport'  		=> 'refresh',
			'type'       		=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'go_first_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'hide_sidebar_input', array(
			'priority' => 30,
			'section'  => 'blog',
			'type'     => 'checkbox',
			'settings' => 'hide_sidebar',
			'label'    => __( 'Hide Sidebar (only applies to the posts page)', 'go-first' ),
		) );

		// Footer
		$wp_customize->add_section( 'footer', array(
			'priority'   => 160,
			'capability' => 'edit_theme_options',
			'title'      => __( 'Footer', 'go-first' ),
		) );

		$wp_customize->add_setting( 'copyright_text', array(
			'default' 			=> '',
			'transport' 		=> 'refresh',
			'type' 				=> 'theme_mod',
			'capability' 		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'copyright_text_input', array(
			'priority' => 10,
			'type'     => 'text',
			'section'  => 'footer',
			'settings' => 'copyright_text',
			'label'    => __( 'Copyright text', 'go-first' ),
		) );

		// Social Networks Links
		$social_networks = array(
			array( 'id' => 'facebook_link',    'name' => 'Facebook', ),
			array( 'id' => 'twitter_link',     'name' => 'Twitter', ),
			array( 'id' => 'instagram_link',   'name' => 'Instagram', ),
			array( 'id' => 'google_plus_link', 'name' => 'Google Plus', ),
			array( 'id' => 'linked_in_link',   'name' => 'LinkedIn', ),
			array( 'id' => 'youtube_link',     'name' => 'YouTube', ),
			array( 'id' => 'pinterest_link',   'name' => 'Pinterest', ),
		);
		$initial_priority = 20;

		foreach ( $social_networks as $social_network ) {
			$wp_customize->add_setting( $social_network['id'], array(
				'default'    		=> '',
				'transport'  		=> 'refresh',
				'type'       		=> 'theme_mod',
				'sanitize_callback' => 'esc_url_raw',
				'capability' 		=> 'edit_theme_options',
			) );

			$wp_customize->add_control( $social_network['id'] . '_input', array(
				'type'        => 'text',
				'section'     => 'footer',
				'priority'    => $initial_priority,
				'settings'    => $social_network['id'],
				/* translators: %s: Social network name */
				'label'       => sprintf( __( '%s link', 'go-first' ), $social_network['name'] ),
				/* translators: %s: Social network name */
				'description' => sprintf( __( 'If not empty a %s icon will appear linking to the provided url', 'go-first' ), $social_network['name'] ),
			) );

			$initial_priority += 10;
		}
		// End Footer

	}
}
