<?php

/**
 * Registers the scripts that will be used at the frontend of the theme.
 *
 * Among the libraries used, the following are: Bootstrap, Google Fonts, Ragrid, Font Awesome and FastClick.
 * 
 * @since 1.0.0
 */
if ( ! function_exists( 'go_first_enqueue_scripts' ) ) {
	function go_first_enqueue_scripts() {
		// Register styles
		wp_register_style( 'go-first-google-fonts', 'https://fonts.googleapis.com/css?family=Roboto:300,400,700' );
		wp_register_style( 'bootstrap', get_template_directory_uri() . '/assets/lib/bootstrap/css/bootstrap.css' );
		wp_register_style( 'font-awesome', get_template_directory_uri() . '/assets/lib/font-awesome/css/font-awesome.css' );
		wp_register_style( 'ragrid', get_template_directory_uri() . '/assets/lib/ragrid/ragrid.css' );
		wp_register_style( 'style', get_stylesheet_uri() );

		// Enqueue styles
		wp_enqueue_style( 'go-first-google-fonts' );
		wp_enqueue_style( 'bootstrap' );
		wp_enqueue_style( 'font-awesome' );
		wp_enqueue_style( 'ragrid' );
		wp_enqueue_style( 'style' );

		// Register scripts
		wp_register_script( 'fastclick', get_template_directory_uri() . '/assets/lib/fastclick/fastclick.js' );
		wp_register_script( 'reframe', get_template_directory_uri() . '/assets/lib/reframe.js/jquery.reframe.js', array('jquery'), null, true );
		wp_register_script( 'main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), null, true );
		wp_register_script( 'header', get_template_directory_uri() . '/assets/js/header.js', array('jquery'), null, true );
		wp_register_script( 'footer', get_template_directory_uri() . '/assets/js/footer.js', array('jquery'), null, true );
		wp_register_script( 'widgets', get_template_directory_uri() . '/assets/js/widgets.js', array('jquery'), null, true );

		// Enqueue scripts
		wp_enqueue_script( 'fastclick' );
		wp_enqueue_script( 'reframe' );
		wp_enqueue_script( 'main' );
		wp_enqueue_script( 'header' );
		wp_enqueue_script( 'footer' );
		wp_enqueue_script( 'widgets' );

		if ( is_singular() ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
}
