<?php

/**
 * Calls all the functions to be run during the wp_head action hook.
 *
 * @since 1.3.0
 */
if ( ! function_exists( 'go_first_wp_head' ) ) {
    function go_first_wp_head() {
        go_first_header_textcolor();
        go_first_header_image();
    }
}

/** 
 * Checks if header text color is set and applies it.
 * 
 * @since 1.3.0
 */
if ( ! function_exists( 'go_first_header_textcolor' ) ) {
    function go_first_header_textcolor() {
        $header_textcolor = get_header_textcolor();
        
        if ( ! empty( $header_textcolor ) ) {
            ?>
                <style type="text/css">
                    .gf-header * {
                        color: #<?php echo esc_html( $header_textcolor ); ?> !important /* So we can override default theme styles */
                    }
                </style>
            <?php
        }
    }
}

/** 
 * Checks if header image is set and applies it.
 * 
 * @since 1.3.0
 */
if ( ! function_exists( 'go_first_header_image' ) ) {
    function go_first_header_image() {
        $header_image_data = get_theme_mod( 'header_image_data' );
        
        if ( ! empty( $header_image_data ) ) {
            ?>
                <style type="text/css">
                    .gf-header {
                        background-image: url(<?php echo esc_url( get_theme_mod( 'header_image' ) ); ?>);
                        background-repeat: no-repeat;
                        background-position: center center;
                        background-size: cover;
                    }
                </style>
            <?php
        }
    }
}